# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).
#{nixpkgs, nixpkgs_unstable, nix_software_center}:

{ config, pkgs, lib, inputs, ... }:

{
  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    adw-gtk3
    aspellDicts.fr #dictionary to spellcheck gnome apps
    aspellDicts.en #dictionary to spellcheck gnome apps
    hunspellDicts.fr-any #dictionary to spellcheck other apps
    hunspellDicts.en_US #dictionary to spellcheck other apps
    hunspellDicts.en_CA #dictionary to spellcheck other apps
    hunspellDicts.en_AU #dictionary to spellcheck other apps
    hunspellDicts.en_GB-ize #dictionary to spellcheck other apps
    affine
#    inputs.affinity-nix.packages.x86_64-linux.photo
#    inputs.affinity-nix.packages.x86_64-linux.designer
#    inputs.affinity-nix.packages.x86_64-linux.publisher
    android-tools
    apache-directory-studio
    audacity
    avidemux
    baobab
    bat # modern cat command
    calibre
    carburetor
    clapgrep
    clementine
    cobang
#    cosmic-ext-applet-clipboard-manager
#    cosmic-ext-applet-external-monitor-brightness
    cosmic-ext-calculator
    cosmic-ext-tweaks
    cosmic-player
#    cosmic-reader
    cosmic-wallpapers
    cromite
    dconf-editor
    diebahn #Railway
    drawing
    dmidecode
    digikam
    duf #modern df command
    element-desktop
    examine
    eza # modern ls command
    fd # modern find command
    ffmpeg
    filezilla
    firefox-devedition
    firefoxpwa
    flameshot
    fontforge
    forecast
    freetube
    fractal
    gcolor3
    gearlever #manage appimage
    gimp
    git
    gnome-obfuscate
    grsync
    gparted
    gpxsee
    gscan2pdf
    gtkhash
    gittyup
    handbrake
    hardinfo2
    heimdall
    heimdall-gui
    httpie # modern wget and curl command
    httrack
    imagemagick
    inkscape-with-extensions
    jitsi-meet-electron
    libsForQt5.kdenlive
    keepassxc
    klavaro
    libreoffice-qt
    loupe
    marktext
    mission-center
    mousai
    naps2 # Scan documents to PDF and more, as simply as possible
    nautilus-python
    neohtop
    nextcloud-client
    nextcloud-talk-desktop
    ncdu # modern du command
    obs-studio
    onlyoffice-bin_latest
    openshot-qt
    openssl
    openvpn3
    papers # remplaçant de evince
    pdf4qt
    pdfarranger
    php
    publii
#    pulsar
    python3
    quick-webapps
    remmina
    resources
    rustdesk-flutter
    servo
    simple-scan
    soundconverter
    sportstracker
    subtitleeditor
    teams-for-linux
    textpieces
    tor-browser
    thunderbird
    traceroute
    transmission_4-gtk
    tribler
    tuba
    ungoogled-chromium
    vdhcoapp
    ventoy
    vlc
    vorta
    vscodium
    wget
    wifi-qr
    wl-clipboard  # to add clipboard sharing with waydroid
    zed-editor
#    zettlr #Marion aime bien Marktext pour l'instant
#    zombietrackergps
#    inputs.nixpkgs_unstable.legacyPackages."${pkgs.system}".NOMDEPAQUET
  ];

  environment.sessionVariables.NIXOS_OZONE_WL = "1"; # turn on native wayland support in all chrome and most electron

  programs = {
    firefox = {
      enable = true;
#      package = pkgs.firefox;
      package = pkgs.librewolf;
      wrapperConfig.pipewireSupport = true;
      nativeMessagingHosts.packages = with pkgs; [
        browserpass
        gnomeExtensions.gsconnect
        firefoxpwa
      ];
    };
    kdeconnect = {
      enable = true;
      package = pkgs.gnomeExtensions.gsconnect;
    };
    appimage = {
      enable = true;
      binfmt = true;
    };
  };

#  services.tor = {
#    enable = true;
#    settings = {
#      ExitNodes = "fr";
#      StrictNodes = "1";
#    };
#  };

  services.flatpak.enable = true;
  systemd.services.flatpak-repo = {
    wantedBy = [ "multi-user.target" ];
    path = [ pkgs.flatpak ];
    script = ''
      flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo
    '';
  };

  nixpkgs = {
    config = {
      permittedInsecurePackages = [
#        "pulsar-1.128.0"
        "ventoy-1.1.05"
      ];
      allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
        "cnijfilter2"
        "corefonts"
        "ventoy"
      ];
    };
  };

  virtualisation = {
    libvirtd = {
      enable = true;
      qemu = {
        swtpm.enable = true;
        ovmf.packages = [ pkgs.OVMFFull.fd ];
      };
    };
    spiceUSBRedirection.enable = true;
    waydroid.enable = true;
  };
  programs.virt-manager.enable = true;

  fonts = {
    packages = with pkgs; [
      corefonts
      ubuntu-sans
      ubuntu-classic
      ubuntu-sans-mono
    ];
    fontconfig = {
      defaultFonts.emoji = [
        "Noto Color Emoji"
      ];
      useEmbeddedBitmaps = true;
    };
  };

}
